jactorch.vision.smooth
======================

.. automodule:: jactorch.vision.smooth

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      GaussianSmooth
      GaussianSmoothTruncated
      MaximumSmooth
      NormalizedBoxSmooth
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      gaussian_smooth
      gaussian_smooth_truncated
      maximum_smooth
      normalized_box_smooth
   
   

   
   
   








.. rubric:: Class GaussianSmooth
.. autoclass:: GaussianSmooth
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class GaussianSmoothTruncated
.. autoclass:: GaussianSmoothTruncated
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MaximumSmooth
.. autoclass:: MaximumSmooth
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class NormalizedBoxSmooth
.. autoclass:: NormalizedBoxSmooth
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: gaussian_smooth

.. autofunction:: gaussian_smooth_truncated

.. autofunction:: maximum_smooth

.. autofunction:: normalized_box_smooth


